embassy-nrf

Crates

git

Versions

nrf9161-ns

Flavors

Atbreplicator

Struct Atbreplicator 

pub struct Atbreplicator { /* private fields */ }
ATB Replicator module

Implementations

Source

impl Atbreplicator

pub const unsafe fn from_ptr(ptr: *mut ()) -> Atbreplicator

pub const fn as_ptr(&self) -> *mut ()

pub const fn idfilter0(self) -> Reg<Idfilter0, RW>

The IDFILTER0 register enables the programming of ID filtering for master port 0.

pub const fn idfilter1(self) -> Reg<Idfilter1, RW>

The IDFILTER1 register enables the programming of ID filtering for master port 1.

pub const fn itatbctr1(self) -> Reg<Itatbctr1, RW>

The ITATBCTR1 register returns the value of the atreadym0, atreadym1, and atvalids inputs in integration mode.

pub const fn itatbctr0(self) -> Reg<Itatbctr0, RW>

The ITATBCTR0 register controls the value of the atvalidm0, atvalidm1, and atreadys outputs in integration mode.

pub const fn itctrl(self) -> Reg<Itctrl, RW>

The ITCTRL register enables the component to switch from a functional mode, which is the default behavior, to integration mode where the inputs and outputs of the component can be directly controlled for the purposes of integration testing and topology detection.

pub const fn claimset(self) -> Reg<Claimset, RW>

Software can use the claim tag to coordinate application and debugger access to trace unit functionality. The claim tags have no effect on the operation of the component. The CLAIMSET register sets bits in the claim tag, and determines the number of claim bits implemented.

pub const fn claimclr(self) -> Reg<Claimclr, RW>

Software can use the claim tag to coordinate application and debugger access to trace unit functionality. The claim tags have no effect on the operation of the component. The CLAIMCLR register sets the bits in the claim tag to 0 and determines the current value of the claim tag.

pub const fn lar(self) -> Reg<Lar, RW>

This is used to enable write access to device registers.

pub const fn lsr(self) -> Reg<Lsr, RW>

This indicates the status of the lock control mechanism. This lock prevents accidental writes by code under debug. Accesses to the extended stimulus port registers are not affected by the lock mechanism. This register must always be present although there might not be any lock access control mechanism. The lock mechanism, where present and locked, must block write accesses to any control register, except the Lock Access Register. For most components this covers all registers except for the Lock Access Register.

pub const fn authstatus(self) -> Reg<Authstatus, RW>

Indicates the current level of tracing permitted by the system

pub const fn devid(self) -> Reg<Devid, R>

Indicates the capabilities of the component.

pub const fn devtype(self) -> Reg<Devtype, R>

The DEVTYPE register provides a debugger with information about the component when the Part Number field is not recognized. The debugger can then report this information.

pub const fn pidr4(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn pidr_0(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn pidr_1(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn pidr_2(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn pidr_3(self) -> Reg<u32, RW>

Coresight peripheral identification registers.

pub const fn cidr_0(self) -> Reg<u32, RW>

Coresight component identification registers.

pub const fn cidr_1(self) -> Reg<u32, RW>

Coresight component identification registers.

pub const fn cidr_2(self) -> Reg<u32, RW>

Coresight component identification registers.

pub const fn cidr_3(self) -> Reg<u32, RW>

Coresight component identification registers.